==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkFocalPlaneContourRepresentation.java <==
// java wrapper for vtkFocalPlaneContourRepresentation object
//

package vtk;
import vtk.*;

public class vtkFocalPlaneContourRepresentation extends vtkContourRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetIntermediatePointWorldPosition_2(int id0,int id1,double id2[]);
  public int GetIntermediatePointWorldPosition(int id0,int id1,double id2[])
    { return GetIntermediatePointWorldPosition_2(id0,id1,id2); }

  private native int GetIntermediatePointDisplayPosition_3(int id0,int id1,double id2[]);
  public int GetIntermediatePointDisplayPosition(int id0,int id1,double id2[])
    { return GetIntermediatePointDisplayPosition_3(id0,id1,id2); }

  private native int GetNthNodeDisplayPosition_4(int id0,double id1[]);
  public int GetNthNodeDisplayPosition(int id0,double id1[])
    { return GetNthNodeDisplayPosition_4(id0,id1); }

  private native int GetNthNodeWorldPosition_5(int id0,double id1[]);
  public int GetNthNodeWorldPosition(int id0,double id1[])
    { return GetNthNodeWorldPosition_5(id0,id1); }

  private native void UpdateContourWorldPositionsBasedOnDisplayPositions_6();
  public void UpdateContourWorldPositionsBasedOnDisplayPositions()
    { UpdateContourWorldPositionsBasedOnDisplayPositions_6(); }

  private native int UpdateContour_7();
  public int UpdateContour()
    { return UpdateContour_7(); }

  private native void UpdateLines_8(int id0);
  public void UpdateLines(int id0)
    { UpdateLines_8(id0); }

  public vtkFocalPlaneContourRepresentation() { super(); }

  public vtkFocalPlaneContourRepresentation(long id) { super(id); }

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkFocalPlaneContourRepresentation.java <==
// java wrapper for vtkFocalPlaneContourRepresentation object
//

package vtk;
import vtk.*;

public class vtkFocalPlaneContourRepresentation extends vtkContourRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetIntermediatePointWorldPosition_2(int id0,int id1,double id2[]);
  public int GetIntermediatePointWorldPosition(int id0,int id1,double id2[])
    { return GetIntermediatePointWorldPosition_2(id0,id1,id2); }

  private native int GetIntermediatePointDisplayPosition_3(int id0,int id1,double id2[]);
  public int GetIntermediatePointDisplayPosition(int id0,int id1,double id2[])
    { return GetIntermediatePointDisplayPosition_3(id0,id1,id2); }

  private native int GetNthNodeDisplayPosition_4(int id0,double id1[]);
  public int GetNthNodeDisplayPosition(int id0,double id1[])
    { return GetNthNodeDisplayPosition_4(id0,id1); }

  private native int GetNthNodeWorldPosition_5(int id0,double id1[]);
  public int GetNthNodeWorldPosition(int id0,double id1[])
    { return GetNthNodeWorldPosition_5(id0,id1); }

  private native void UpdateContourWorldPositionsBasedOnDisplayPositions_6();
  public void UpdateContourWorldPositionsBasedOnDisplayPositions()
    { UpdateContourWorldPositionsBasedOnDisplayPositions_6(); }

  private native int UpdateContour_7();
  public int UpdateContour()
    { return UpdateContour_7(); }

  private native void UpdateLines_8(int id0);
  public void UpdateLines(int id0)
    { UpdateLines_8(id0); }

  public vtkFocalPlaneContourRepresentation() { super(); }

  public vtkFocalPlaneContourRepresentation(long id) { super(id); }

}
